@@ -1,7 +1,7 @@
-__version__ = "0.9.1"
-__version_info__ = ['0', '9', '1']
+__version__ = "0.10"
+__version_info__ = ['0', '10']
 __version_vcs_info__ = {'branch': 'master',
- 'revid': '715e737',
- 'revno': 1511,
+ 'revid': '8f651db',
+ 'revno': 1798,
  'toplevel': '/home/saxtouri/src/kamaki/kamaki'}
 __version_user_info__ = "saxtouri@terminus"
